# TurboDL Tests

Ensures that all TurboDL features are not broken.

---

# Usage

### Running the tests

Run the tests with the following command:

```bash
poetry run pytest -v --xfail-tb
```

Or through Makefile:

```bash
make tests
```
